@@ -1,19 +1,22 @@
 import os.path
-
-from clint.textui.progress import Bar as ProgressBar
-from requests_toolbelt import MultipartEncoder, MultipartEncoderMonitor
-
-from .exceptions import LoginException, UploadException
-from .config import get_config_value
+from json import JSONDecodeError
 
 import requests
+from requests_toolbelt import MultipartEncoder, MultipartEncoderMonitor
+
+from .config import get_config_value
+from .exceptions import LoginException, UploadException
+from .constants import UNHANDLED_EXCEPTION_MSG
+from .helper import ProgressBar
 
 DEBUG = os.environ.get("SHIPPY_DEBUG", default=0)
 
 
 def undef_response_exp(r):
-    raise Exception("Unhandled error. Contact the admins for help. Response code from server: {} \n Response from "
-                    "server: {}".format(r.status_code, r.json()))
+    try:
+        raise Exception(UNHANDLED_EXCEPTION_MSG.format(r.url, r.status_code, r.json()))
+    except JSONDecodeError:
+        raise Exception(UNHANDLED_EXCEPTION_MSG.format(r.url, r.status_code, r.content))
 
 
 def get_server_version(server_url):
@@ -49,8 +52,10 @@ def upload_to_server(build_file, checksum_file, server_url, token, use_chunked_u
     print("Uploading build {}...".format(build_file))
 
     if use_chunked_upload:
+        print("Using chunked upload method to upload...")
         chunked_upload(server_url, build_file, checksum_file, token)
     else:
+        print("Using direct upload method to upload...")
         direct_upload(server_url, build_file, checksum_file, token)
 
 
@@ -84,11 +89,11 @@ def chunked_upload(server_url, build_file, checksum_file, token):
                     print("Status code received from server: {}".format(r.status_code))
                     with open('output.html', 'wb') as error_output_raw:
                         error_output_raw.write(r.content)
-                raise UploadException(detail="Something went wrong during the upload.", retry=False)
+                raise UploadException("Something went wrong during the upload.")
 
     print("")  # Clear progress bar from screen
 
-    # Complete upload
+    # Finalize upload to begin processing
     r = requests.post(device_upload_url, headers={"Authorization": "Token {}".format(token)},
                       data={'md5': get_md5_from_file(checksum_file)})
 
@@ -144,23 +149,21 @@ def upload_exception_check(r, build_file):
         return
     elif r.status_code == 400:
         if r.json()['error'] == "duplicate_build":
-            raise UploadException(detail="This build already exists in the system!", retry=False)
+            raise UploadException("This build already exists in the system!")
         elif r.json()['error'] == "missing_files":
-            raise UploadException(detail="One of the required fields are missing!", retry=False)
+            raise UploadException("One of the required fields are missing!")
         elif r.json()['error'] == "file_name_mismatch":
-            raise UploadException(detail="The build file name does not match the checksum file name!", retry=False)
+            raise UploadException("The build file name does not match the checksum file name!")
         elif r.json()['error'] == "invalid_file_name":
-            raise UploadException(detail="The file name was malformed!", retry=False)
+            raise UploadException("The file name was malformed!")
         elif r.json()['error'] == "not_official":
-            raise UploadException(detail="The build is not official!", retry=False)
+            raise UploadException("The build is not official!")
         elif r.json()['error'] == "codename_mismatch":
-            raise UploadException(detail="The codename does not match the build file name!", retry=False)
+            raise UploadException("The codename does not match the build file name!")
     elif r.status_code == 401:
         if r.json()['error'] == "insufficient_permissions":
-            raise UploadException(detail="You are not allowed to upload for this device!", retry=False)
-    elif r.status_code == 500:
-        raise UploadException(detail="An internal server error occurred. Contact the administrators for help.",
-                              retry=False)
+            raise UploadException("You are not allowed to upload for this device!")
+    elif r.status_code[0] == 5:
+        raise UploadException("Something went wrong with the server. Please contact the admins.")
 
-    print("A problem occurred while uploading your build.")
     undef_response_exp(r)
